==> nextcloud-25.0.12.tgz: nextcloud/apps/serverinfo/l10n/sl.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Podatki CPE niso na voljo",
    "Not supported!" : "Ni podprto!",
    "Press ⌘-C to copy." : "Pritisnite ⌘-C za kopiranje.",
    "Press Ctrl-C to copy." : "Pritisnite Ctrl-C za kopiranje.",
    "System" : "Sistem",
    "Monitoring" : "Sistemska dejavnost",
    "Monitoring app with useful server information" : "Program za spremljanje delovanja sistema z različnimi podrobnostmi obremenitve strežnika",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Omogoča prikaz različnih podrobnosti strežnika, kot so obremenitev CPE, zasedenost pomnilnika in prostora, števila uporabnikov in drugo.",
    "Temperature" : "Temperatura",
    "Load" : "Obremenitev",
    "Memory" : "Pomnilnik",
    "Disk" : "Disk",
    "Size:" : "Velikost:",
    "Files:" : "Datoteke:",
    "Storages:" : "Shrambe:",
    "Free Space:" : "Prostor:",
    "Network" : "Omrežje",
    "Active users" : "Dejavni uporabniki",
    "Total users:" : "Število uporabnikov:",
    "Shares" : "Souporaba",
    "Users:" : "Uporabniki:",
    "PHP" : "Okolje PHP",
    "Version:" : "Različica:",
    "Upload max size:" : "Omejitev velikosti pošiljanja:",
    "Unable to list extensions" : "Ni mogoče izpisati seznama razširitev",
    "Database" : "Podatkovna zbirka",
    "Type:" : "Vrsta:",
    "External monitoring tool" : "Zunanje orodje za nadzor",
    "You can connect an external monitoring tool by using this end point:" : "Povezava do zunanjega orodja za spremljanje delovanja prek končne točke:",
    "Copy" : "Kopiraj",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON." : "Pripenjanje zapisa » ?format=json « na konec naslova URL omogoči izpis podatkov v zapisu JSON.",
    "You will get a notification once one of your disks is nearly full." : "Obvestilo bo poslano, ko bo katerikoli disk skoraj polno zaseden."
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");

==> nextcloud-26.0.9.tgz: nextcloud/apps/serverinfo/l10n/sl.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Podatki CPE niso na voljo",
    "Copied!" : "Kopirano!",
    "Not supported!" : "Ni podprto!",
    "Press ⌘-C to copy." : "Pritisnite ⌘-C za kopiranje.",
    "Press Ctrl-C to copy." : "Pritisnite Ctrl-C za kopiranje.",
    "System" : "Sistem",
    "Monitoring" : "Sistemska dejavnost",
    "Monitoring app with useful server information" : "Program za spremljanje delovanja sistema z različnimi podrobnostmi obremenitve strežnika",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Omogoča prikaz različnih podrobnosti strežnika, kot so obremenitev CPE, zasedenost pomnilnika in prostora, števila uporabnikov in drugo.",
    "Temperature" : "Temperatura",
    "Load" : "Obremenitev",
    "Memory" : "Pomnilnik",
    "Disk" : "Disk",
    "Size:" : "Velikost:",
    "Files:" : "Datoteke:",
    "Storages:" : "Shrambe:",
    "Free Space:" : "Prostor:",
    "Network" : "Omrežje",
    "Active users" : "Dejavni uporabniki",
    "Total users:" : "Število uporabnikov:",
    "Shares" : "Souporaba",
    "Users:" : "Uporabniki:",
    "PHP" : "Okolje PHP",
    "Version:" : "Različica:",
    "Upload max size:" : "Omejitev velikosti pošiljanja:",
    "Unable to list extensions" : "Ni mogoče izpisati seznama razširitev",
    "Database" : "Podatkovna zbirka",
    "Type:" : "Vrsta:",
    "External monitoring tool" : "Zunanje orodje za nadzor",
    "Copy" : "Kopiraj",
    "You will get a notification once one of your disks is nearly full." : "Obvestilo bo poslano, ko bo katerikoli disk skoraj polno zaseden.",
    "You can connect an external monitoring tool by using this end point:" : "Povezava do zunanjega orodja za spremljanje delovanja prek končne točke:",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON." : "Pripenjanje zapisa » ?format=json « na konec naslova URL omogoči izpis podatkov v zapisu JSON."
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
